<?php

namespace Hostim\Section;

use Elementor\{Widget_Base,
	Controls_Manager,
	Group_Control_Border,
	Group_Control_Typography,
	Group_Control_Text_Shadow,
	Group_Control_Background,
	Frontend,
	Repeater,
	Plugin,
	Shapes
};

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Elementor Section
 *
 * @class        Hostim_Section
 * @version      1.0
 * @category Class
 * @author       ThemeTags
 */
class Hostim_Section {


	public $sections = [];

	public function __construct() {

		add_action( 'elementor/init', [ $this, 'add_hooks' ] );
	}

	public function add_hooks() {

		add_action( 'elementor/element/section/section_typo/after_section_end', [ $this, 'extened_animation' ], 10, 2 );

		add_action( 'elementor/frontend/section/before_render', [ $this, 'extened_row_render' ], 10, 1 );
		
		add_action( 'elementor/frontend/column/before_render', [ $this, 'extened_column_render' ], 10, 1 );

		add_action( 'elementor/frontend/before_enqueue_scripts', [ $this, 'enqueue_scripts' ] );

		add_action( 'elementor/element/wp-post/document_settings/after_section_end', [ $this, 'post_metaboxes' ], 10, 1 );

		$dark_mode = hostim_option('is_dark_mode', false);
		if ($dark_mode) {
			
			add_action('elementor/element/after_section_end', function( $section, $section_id ) {

				if ( 'section_advanced' === $section_id || '_section_style' === $section_id ) {
					#Start Custom Settings Section
					$section->start_controls_section(
						'dark_light_color_section',
						[
							'label' => __( 'Dark Mode Color', 'hostim-core' ),
							'tab' => \Elementor\Controls_Manager::TAB_ADVANCED,
						]
					);
					$section->add_control(
						'dark_mode_text_color',
						[
							'label' => esc_html__('Text Color', 'hostim-core'),
							'type' => \Elementor\Controls_Manager::COLOR,
							'selectors' => [
								'[data-bs-theme=dark] {{WRAPPER}}.elementor-widget-hostim-button .hostim-btn-wrapper .hostim-btn span' => 'color: {{VALUE}}',
							],
						]
					);
					$section->add_group_control(
						\Elementor\Group_Control_Background::get_type(),
						[
							'name' => 'dark_background',
							'types' => ['classic', 'gradient'],
							'selector' => '
								[data-bs-theme=dark] {{WRAPPER}}.elementor-section, 
								[data-bs-theme=dark] {{WRAPPER}}.elementor-column > .elementor-element-populated,
								[data-bs-theme=dark] {{WRAPPER}}.elementor-column > .elementor-widget-container,
								[data-bs-theme=dark] {{WRAPPER}}.elementor-column > .elementor-widget-container .elementor-button,
								[data-bs-theme=dark] {{WRAPPER}} > .elementor-widget-container,
								[data-bs-theme=dark] {{WRAPPER}} > .elementor-widget-container > .hostim-btn
							',
						]
					);

					#End Custom Settings Section
					$section->end_controls_section();
				}
			}, 10, 2 );

			// add_action('elementor/frontend/section/before_render', function ($element) {
			// 	$v = (object)$element->get_settings_for_display();

			// });
		}

	}


	function post_metaboxes( $page ) {

		$page->start_controls_section( 'header_options', [
			'label' => esc_html__( 'Hostim Header Options', 'hostim-core' ),
			'tab'   => Controls_Manager::TAB_SETTINGS,
		] );

		$page->add_control( 'mobile_breakpoint', [
			'label'   => esc_html__( 'Mobile Header resolution breakpoint', 'hostim-core' ),
			'type'    => Controls_Manager::NUMBER,
			'step'    => 1,
			'min'     => 5,
			'max'     => 4000,
			'default' => 1200,
		] );

		$page->add_control( 'header_on_bg', [
			'label'        => esc_html__( 'Over content?', 'hostim-core' ),
			'description'  => esc_html__( 'Set Header to display over content.', 'hostim-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__( 'On', 'hostim-core' ),
			'label_off'    => esc_html__( 'Off', 'hostim-core' ),
			'return_value' => 'yes',
		] );

		$page->end_controls_section();


	}

	public function extened_row_render( \Elementor\Element_Base $element ) {

		

	}

	public function extened_column_render( \Elementor\Element_Base $element ) {

		
	}

	public function enqueue_scripts() {

		wp_enqueue_script( 'tt-parallax', esc_url( TT_ELEMENTOR_ADDONS_URL . 'assets/js/tt_elementor_sections.js' ), [ 'jquery' ], false, true );

		wp_localize_script( 'tt-parallax', 'tt_parallax_settings', [
			$this->sections,
			'ajaxurl' => admin_url( 'admin-ajax.php' ),
		] );


	}

	public function extened_animation( $widget, $args ) {

		$widget->start_controls_section( 'extened_shape', [
			'label' => esc_html__( 'Hostim Shape', 'hostim-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );
		$widget->add_control( 'add_background_animation', [
			'label'        => esc_html__( 'Add Extended Background Animation?', 'hostim-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__( 'On', 'hostim-core' ),
			'label_off'    => esc_html__( 'Off', 'hostim-core' ),
			'return_value' => 'yes',
		] );

		$repeater = new Repeater();
		
		$repeater->add_control( 'image_bg', [
			'label'       => esc_html__( 'Parallax Image', 'hostim-core' ),
			'type'        => Controls_Manager::MEDIA,
			'label_block' => true,
			'default'     => [
				'url' => '',
			],
		] );

		$repeater->add_responsive_control( 'position_top', [
			'label'       => esc_html__( 'Top Offset', 'hostim-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [ 'min' => - 100, 'max' => 100 ],
				'px' => [ 'min' => - 200, 'max' => 1000, 'step' => 5 ],
			],
			'default'     => [ 'size' => 0, 'unit' => '%' ],
			'description' => esc_html__( 'Set figure vertical offset from top border.', 'hostim-core' ),
			'selectors'   => [
				"{{WRAPPER}} {{CURRENT_ITEM}}" => 'top: {{SIZE}}{{UNIT}}',
			],
		] );

		$repeater->add_responsive_control( 'position_left', [
			'label'       => esc_html__( 'Left Offset', 'hostim-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [
					'min' => - 100,
					'max' => 100,
				],
				'px' => [
					'min'  => - 200,
					'max'  => 1000,
					'step' => 5,
				],
			],
			'default'     => [
				'unit' => '%',
				'size' => 0,
			],
			'description' => esc_html__( 'Set figure horizontal offset from left border.', 'hostim-core' ),
			'selectors'   => [
				"{{WRAPPER}} {{CURRENT_ITEM}}" => 'left: {{SIZE}}{{UNIT}}',
			],
		] );

		$repeater->add_control( 'image_index', [
			'label'     => esc_html__( 'Image z-index', 'hostim-core' ),
			'type'      => Controls_Manager::NUMBER,
			'step'      => 1,
			'default'   => 0,
			'selectors' => [
				"{{WRAPPER}} {{CURRENT_ITEM}}" => 'z-index: {{UNIT}}',
			],
		] );

		$repeater->add_control( 'hide_on_mobile', [
			'label'        => esc_html__( 'Hide On Mobile?', 'hostim-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__( 'On', 'hostim-core' ),
			'label_off'    => esc_html__( 'Off', 'hostim-core' ),
			'return_value' => 'yes',
		] );
		$repeater->add_control( 'hide_mobile_resolution', [
			'label'     => esc_html__( 'Screen Resolution', 'hostim-core' ),
			'type'      => Controls_Manager::NUMBER,
			'step'      => 1,
			'default'   => 768,
			'condition' => [
				'hide_on_mobile' => 'yes',
			],
		] );

		$widget->add_control( 'items_parallax', [
			'label'     => esc_html__( 'Layers', 'hostim-core' ),
			'type'      => Controls_Manager::REPEATER,
			'fields'    => $repeater->get_controls(),
			'condition' => [
				'add_background_animation' => 'yes',
			],
		] );

		$widget->end_controls_section();


	}


}