<?php

namespace Hostim\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Group_Control_Background,
	Group_Control_Box_Shadow,
	Widget_Base,
	Controls_Manager,
	Group_Control_Typography,
	Group_Control_Border};


class Hostim_features extends Widget_Base {

	public function get_name() {
		return 'hostim-features';
	}

	public function get_title() {
		return __( 'Hostim Features', 'hostim-core' );
	}

	public function get_icon() {
		return 'eicon-gallery-grid';
	}

	public function get_categories() {
		return [ 'hostim-elements' ];
	}


	protected function register_controls() {

		// Layout =====================
		$this->start_controls_section( 'section_feature', [
			'label' => __( 'Features Style', 'hostim-core' ),
		] );

		$this->add_control( 'layout', [
			'label'   => esc_html__( 'Layout', 'hostim-core' ),
			'type'    => Controls_Manager::SELECT,
			'options' => [
				'1' => esc_html__( 'Layout 1', 'hostim-core' ),
				'2' => esc_html__( 'Layout 2', 'hostim-core' ),
			],
			'default' => '1',
		] );
		$this->end_controls_section();


		$this->start_controls_section( 'section_features', [
			'label' => __( 'Features', 'hostim-core' ),
			'condition' => [
				'layout' => '1'
			]
		] );		

		$repeater = new \Elementor\Repeater();

		$repeater->add_control( 'feature_title', [
			'label'       => __( 'Title', 'hostim-core' ),
			'type'        => Controls_Manager::TEXTAREA,
			'default'	  => __('Maximum <br> Security', 'hostim-core')
		] );

		$repeater->add_control( 'feature_desc', [
			'label'       => __( 'Description', 'hostim-core' ),
			'type'        => Controls_Manager::TEXTAREA,
			'default'	  => __('Choice for growing agencies and support that acts asyour ecommerce businesses.', 'hostim-core')
		] );

		$repeater->add_control( 'selected_icon', [
			'label'   => __( 'Icon', 'hostim-core' ),
			'type'    => Controls_Manager::ICONS,
			'default' => [
				'value'   => 'fas fa-check',
				'library' => 'solid',
			],
		] );

		$repeater->add_control( 'feature_link', [
			'label'       => __( 'URL', 'hostim-core' ),
			'type'        => Controls_Manager::URL,
			'default'	  => [
				'url'	=> '#'
			]
		] );

		$this->add_control( 'features_list', [
			'label'       => __( 'Features List', 'hostim-core' ),
			'type'        => \Elementor\Controls_Manager::REPEATER,
			'fields'      => $repeater->get_controls(),
			'default'     => [
				[
					'feature_title' => __( '15+ Years Web Hosting Company', 'hostim-core' ),
					'feature_desc'   => __( 'Traditional WordPress, you get all the features, tools, and guidance you need to build and launch.', 'hostim-core' ),
					'selected_icon' => [
						'value'   => 'fas fa-check',
						'library' => 'solid',
					]
				],
			],
			'title_field' => '{{{ feature_title }}}',
		] );
		$this->end_controls_section();


		// Features Tab ===============================
		$this->start_controls_section( 'features_tab', [
			'label' => __( 'Features Tab', 'hostim-core' ),
			'condition' => [
				'layout' => '2'
			]
		] );

		$features = new \Elementor\Repeater();

		$features->add_control( 'feature_cat', [
			'label'       => __( 'Feature Category', 'hostim-core' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
			'default'	  => 'VPS Feature'
		] );
		
		$features->add_control( 'tab_title', [
			'label'       => __( 'Title', 'hostim-core' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
			'default'	  => 'Solid State Drives (SSD)'
		] );

		$features->add_control( 'description', [
			'label'       => __( 'Description', 'hostim-core' ),
			'type'        => Controls_Manager::TEXTAREA,
			'label_block' => true,
			'default'	  => 'Dynamically negotiate technologies after bricks-and-clicks portals. Competently deliver client-focused niche markets before parallel task pandemic.'
		] );

		$features->add_control( 'feature_img', [
			'label'       => __( 'Feature image', 'hostim-core' ),
			'type'        => Controls_Manager::MEDIA,

		] );

		$features->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'sec_background',
				'label' => esc_html__( 'Background', 'plugin-name' ),
				'types' => [ 'classic', 'gradient' ],
				'fields_options' => [
					'size' => ['default' => 'cover'],
					'position' => ['default' => 'bottom right'],
					'repeat' => ['default' => 'no-repeat'],
				],
				'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}',
			]
		);


		$this->add_control( 'features_tabs', [
			'label'       => __( 'Feature Tabs', 'hostim-core' ),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => $features->get_controls(),
			'default'     => [
				[				
					'feature_cat' => __( 'VPS Feature', 'hostim-core'),
					'tab_title'   => __( 'What is WordPress Hosting', 'hostim-core' ),
					'description' => __( 'We care about safety big time — and so do your site\'s visitors. With a Shared Hosting account, you get an SSL certificate for free to add to your site. In this day and age, having an SSL for your site is a no-brainer best practice. Not only does an SSL help your visitors feel safe interacting with your site — this is particularly important if you run an e-commerce site.', 'hostim-core' ),
				],
				
			],
			'title_field' => '{{{feature_cat}}} - {{{ tab_title }}}',
		] );

		$this->end_controls_section();
		
		
		
		$this->start_controls_section( 'section_features_shape', [
			'label' => __( 'Shapes', 'hostim-core' ),
		] );	

		$this->add_control( 'features_shape_left', [
			'label'   => __( 'Choose Shape Left Image', 'hostim-core' ),
			'type'    => Controls_Manager::MEDIA,
			'default' => [
				'url' => plugin_dir_url( __DIR__ ) . 'assets/images/hero/feature-triangle.svg'
			],
			
		] );
		
		$this->end_controls_section();

		// Style Section ======================
		$this->start_controls_section( 'style_title', [
			'label' => __( 'Heading', 'hostim-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control(
			'heading_margin',
			[
				'label' => esc_html__( 'Margin', 'hostim-core' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .consult-left .consult_heading' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'heading_typo',
			'label'    => __( 'Typography', 'hostim-core' ),
			'selector' => '{{WRAPPER}} .consult-left .consult_heading',
		] );

		$this->add_control( 'heading_color', [
			'label'     => __( 'Color', 'hostim-core' ),
			'type'      => Controls_Manager::COLOR,
			'default'   => '',
			'selectors' => [
				'{{WRAPPER}} .consult-left .consult_heading' => 'color: {{VALUE}};',
			],
		] );
		$this->end_controls_section();
		
		
		// Features List item
		$this->start_controls_section( 'style_list_items', [
			'label' => __( 'Features', 'hostim-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );
		$this->add_control(
			'item_title_heading',
			[
				'label' => __( 'Title', 'hostim-core' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'item_title_typo',
			'label'    => __( 'Typography', 'hostim-core' ),
			'selector' => '{{WRAPPER}} .feature_title_',
		] );

		$this->add_control( 'item_title_color', [
			'label'     => __( 'Color', 'hostim-core' ),
			'type'      => Controls_Manager::COLOR,
			'default'   => '',
			'selectors' => [
				'{{WRAPPER}} .feature_title_' => 'color: {{VALUE}};',
			],
		] );
		
		$this->add_control(
			'item_desc_heading',
			[
				'label' => __( 'Description', 'hostim-core' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'item_desc_typo',
			'label'    => __( 'Typography', 'hostim-core' ),
			'selector' => '{{WRAPPER}} .feature_content_',
		] );

		$this->add_control( 'item_desc_color', [
			'label'     => __( 'Color', 'hostim-core' ),
			'type'      => Controls_Manager::COLOR,
			'default'   => '',
			'selectors' => [
				'{{WRAPPER}} .feature_content_' => 'color: {{VALUE}};',
			],
		] );
		
		$this->add_control(
			'item_icon_heading',
			[
				'label' => __( 'Icon', 'hostim-core' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'layout' => '1'
				]
			]
		);
		$this->start_controls_tabs(
			'icon_style_tabs', [
				'condition' => [
					'layout' => '1'
				]
			]
			
		);

		$this->start_controls_tab(
			'icon_style_normal',
			[
				'label' => esc_html__('Normal', 'hostim-core'),
			]
		);
		$this->add_control('item_icon_color',
			[
				'label'     => __('Icon Color', 'hostim-core'),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => [
					'{{WRAPPER}} .hm2-feature-card .icon-wrapper' => 'color: {{VALUE}};',
					'{{WRAPPER}} .hm2-feature-card .icon-wrapper svg' => 'fill: {{VALUE}};',
				]
			]
		);

		$this->add_control('item_line_color',
			[
				'label'     => __('Background Color', 'hostim-core'),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => [
					'{{WRAPPER}} .hm2-feature-card .icon-wrapper' => 'background-color: {{VALUE}};',
				]
			]
		);

		$this->end_controls_tab();
		
		$this->start_controls_tab(
			'icon_style_hover',
			[
				'label' => esc_html__('Hover', 'hostim-core'),
			]
		);

		$this->add_control('item_icon_hover_color',
			[
				'label'     => __('Icon Color', 'hostim-core'),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => [
					'{{WRAPPER}} .hm2-feature-card:hover .icon-wrapper' => 'color: {{VALUE}};',
					'{{WRAPPER}} .hm2-feature-card:hover .icon-wrapper svg' => 'fill: {{VALUE}};',
				]
			]
		);

		$this->add_control('item_hover_bg',
			[
				'label'     => __('Background Color', 'hostim-core'),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => [
					'{{WRAPPER}} .hm2-feature-card:hover .icon-wrapper' => 'background-color: {{VALUE}};',
				]
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_control(
			'icon_size',
			[
				'label' => esc_html__('Icon Size', 'hostim-core'),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
						'step' => 1,
					],
					
				],
				'default' => [
					'unit' => 'px',
					'size' => 25,
				],
				'selectors' => [
					'{{WRAPPER}} .hm2-feature-card .icon-wrapper i' => 'font-size: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .hm2-feature-card .icon-wrapper svg' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}}',
				],
				'condition' => [
					'layout' => '1'
				]
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'feature_bg',
				'label' => esc_html__('Background', 'plugin-name'),
				'types' => ['classic', 'gradient'],
				'selector' => '{{WRAPPER}} .hm2-feature-card',
			]
		);

		$this->end_controls_section();
		
		$this->start_controls_section( 'style_section', [
			'label' => __( 'Section Background', 'hostim-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );
		$this->add_responsive_control(
			'section_margin',
			[
				'label' => esc_html__( 'Margin', 'hostim-core' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .hm2-feature-area' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'section_padding',
			[
				'label' => esc_html__( 'Padding', 'hostim-core' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .hm2-feature-area' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'sec_background',
				'label' => esc_html__( 'Background', 'plugin-name' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => '{{WRAPPER}} .hm2-feature-area',
			]
		);
		$this->end_controls_section();
	}

	/**
	 * Render button widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		extract( $settings );

		require __DIR__ . '/templates/features/layout-' . $layout . '.php';

		
	}
}