<?php


namespace Hostim\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Controls_Manager,
	Group_Control_Background,
	Group_Control_Box_Shadow,
	Widget_Base,
	Group_Control_Typography,
	Repeater,
	Utils};

class Hostim_Testimonial extends Widget_Base {

	public function get_name() {
		return 'hostim-testimonial';
	}

	public function get_title() {
		return esc_html__( 'Hostim Testimonial', 'hostim-core' );
	}

	public function get_icon() {
		return 'eicon-testimonial';
	}

	public function get_categories() {
		return [ 'hostim-elements' ];
	}

	protected function register_controls() {

		//======================= Select Layout ==========================//
		$this->start_controls_section( 'section_testimonial', [
			'label' => __( 'Testimonial Style', 'hostim-core' ),
		] );

		$this->add_control( 'layout', [
			'label'   => esc_html__( 'Layout', 'hostim-core' ),
			'type'    => Controls_Manager::SELECT,
			'options' => [
				'1' => esc_html__( 'Layout 1', 'hostim-core' ),
				'2' => esc_html__( 'Layout 2 [Carousel]', 'hostim-core' ),
				'3' => esc_html__( 'Layout 3 [Carousel]', 'hostim-core' ),
				'4' => esc_html__( 'Layout 4', 'hostim-core' ),
				'5' => esc_html__( 'Layout 5 [Carousel]', 'hostim-core' ),
				'6' => esc_html__( 'Layout 6 [Carousel]', 'hostim-core' ),
				'7' => esc_html__( 'Layout 7', 'hostim-core' ),
				'8' => esc_html__( 'Layout 8', 'hostim-core' ),
				'9' => esc_html__( 'Layout 9', 'hostim-core' ),
				'10' => esc_html__( 'Layout 10', 'hostim-core' ),
			],
			'default' => '1',
		] );

		$this->end_controls_section(); //End Layout


		//======================== Testimonial Heading ========================//
		$this->start_controls_section( 'testimonial_sec_heading', [
			'label' => esc_html__( 'Testimonial Heading', 'hostim-core' ),
			'condition' => [
				'layout' => [ '1', '4' ]
			]
		] );

		$this->add_control( 'sec_heading', [
			'label'       => __( 'Heading Text', 'hostim-core' ),
			'type'        => Controls_Manager::TEXTAREA,
			'default'     => __( 'Hundreds of five-star Ratings. Every day!', 'hostim-core' ),
			'label_block' => true,
		] );

		$this->add_control( 'sec_short_desc', [
			'label'       => __( 'Short Description', 'hostim-core' ),
			'type'        => Controls_Manager::TEXTAREA,
			'default'     => __( 'We truly cannot say enough about the level of customer service that Kinsta provides - it\'s always a great experience, with very personable and helpful support.', 'hostim-core' ),
			'label_block' => true,
		] );

		$this->end_controls_section(); // End Testimonial Heading


		//=========================== Testimonial =========================//
		$this->start_controls_section( 'section_tab_style', [
			'label' => esc_html__( 'Testimonial', 'hostim-core' ),
		] );

		$this->add_control( 'enable_quote', [
			'label'        => esc_html__( 'Show Quote Icon', 'hostim-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__( 'Show', 'hostim-core' ),
			'label_off'    => esc_html__( 'Hide', 'hostim-core' ),
			'return_value' => 'yes',
			'default'      => 'yes',
            'condition'    => [
                'layout'   => [ '1', '2', '3', '4', '5', '6' ],
            ]
		] );


		$this->add_control( 'quote_image', [
			'label'   => __( 'Quote Image', 'hostim-core' ),
			'type'    => Controls_Manager::MEDIA,
			'default' => [
				'url' => plugin_dir_url(__DIR__) . '/assets/images/testimonial/quote-icon.svg',
			],
			'condition' => [
				'enable_quote' => 'yes',
				'layout'   => [ '1', '2', '3', '4', '5', '6' ],
			]
		] );

		$repeater = new Repeater();
		$repeater->add_control( 'author_image', [
			'label'   => __( 'Author Image', 'hostim-core' ),
			'type'    => Controls_Manager::MEDIA,
			'default' => [
				'url' => plugin_dir_url(__DIR__) . '/assets/images/testimonial/client-1.png',
			]
		] );

		$repeater->add_control( 'name', [
			'label'       => __( 'Name', 'hostim-core' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => __( 'Carrie Roberts', 'hostim-core' ),
			'label_block' => true,
		] );

		$repeater->add_control( 'designation', [
			'label'       => __( 'Designation', 'hostim-core' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => __( 'Co-Founder', 'hostim-core' ),
			'label_block' => true,
		] );

		$repeater->add_control( 'rating', [
			'label'   => __( 'Rating Number', 'hostim-core' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => '50',
			'options' => [
				'10' => __( '1 Star', 'hostim-core' ),
				'20' => __( '2 Star', 'hostim-core' ),
				'30' => __( '3 Star', 'hostim-core' ),
				'40' => __( '4 Star', 'hostim-core' ),
				'50' => __( '5 Star', 'hostim-core' ),
			],
		] );

		$repeater->add_control( 'title', [
			'label'       => __( 'Title', 'hostim-core' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => __( 'Needles to say we are extremely satisfied', 'hostim-core' ),
			'label_block' => true,
		] );

		$repeater->add_control( 'review_content', [
			'label'      => __( 'Review Content', 'hostim-core' ),
			'type'       => Controls_Manager::TEXTAREA,
			'default'    => __( '“If you need any help or assistance we\'d be happy to help. Just reply to this email. Trusted by Agency proud to work many well known brands”', 'hostim-core' ),
			'show_label' => false,
		] );

		$repeater->add_control( 'stamp_image', [
			'label'   => __( 'Stamp Image', 'hostim-core' ),
			'type'    => Controls_Manager::MEDIA,
			'default' => [
				'url' => plugin_dir_url(__DIR__) . '/assets/images/testimonial/stamps.png',
			]
		] );

		$this->add_control( 'testimonials', [
			'label'       => __( 'Testimonial Items', 'hostim-core' ),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => $repeater->get_controls(),
			'title_field' => '{{{ name }}}',
            'condition' => [
                'layout' => [ '1', '2', '3', '4', '5', '6', '8', '9']
            ]
		] );


        //=================== Testimonials 07 ====================//
        $testimonials7 = new Repeater();
        $testimonials7->add_control( 'author_image', [
            'label'   => __( 'Author Image', 'hostim-core' ),
            'type'    => Controls_Manager::MEDIA,
            'default' => [
                'url' => plugin_dir_url(__DIR__) . '/assets/images/testimonial/client-1.png',
            ]
        ] );

        $testimonials7->add_control( 'name', [
            'label'   => __( 'Name', 'hostim-core' ),
            'type'    => Controls_Manager::TEXT,
            'default' => 'Elias M. Jessen'
        ] );

        $testimonials7->add_control( 'designation', [
            'label'   => __( 'Designation', 'hostim-core' ),
            'type'    => Controls_Manager::TEXT,
            'default' => 'Co-Founder'
        ] );

        $testimonials7->add_control( 'review_content', [
            'label'   => __( 'Review Content', 'hostim-core' ),
            'type'    => Controls_Manager::TEXTAREA,
        ] );

        $testimonials7->add_control( 'rating', [
            'label'   => __( 'Rating Number', 'hostim-core' ),
            'type'    => \Elementor\Controls_Manager::SELECT,
            'default' => '50',
            'options' => [
                '10' => __( '1 Star', 'hostim-core' ),
                '20' => __( '2 Star', 'hostim-core' ),
                '30' => __( '3 Star', 'hostim-core' ),
                '40' => __( '4 Star', 'hostim-core' ),
                '50' => __( '5 Star', 'hostim-core' ),
            ],
        ] );

        $this->add_control( 'testimonials7', [
            'label'       => __( 'Testimonial Items', 'hostim-core' ),
            'type'        => Controls_Manager::REPEATER,
            'fields'      => $testimonials7->get_controls(),
            'title_field' => '{{{ name }}}',
            'condition' => [
                'layout' => '7'
            ]
        ] ); //End Testimonials


		//=================== Testimonials 010 ====================//
		$testimonials7 = new Repeater();
		$testimonials7->add_control( 'author_image', [
			'label'   => __( 'Author Image', 'hostim-core' ),
			'type'    => Controls_Manager::MEDIA,
			'default' => [
				'url' => plugin_dir_url(__DIR__) . '/assets/images/testimonial/client-1.png',
			]
		] );

		$testimonials7->add_control( 'title', [
			'label'   => __( 'Title', 'hostim-core' ),
			'type'    => Controls_Manager::TEXT,
			'label_block' => true,
			'default' => 'Needless to say we are extremely satisfied'
		] );


		$testimonials7->add_control( 'name', [
			'label'   => __( 'Name', 'hostim-core' ),
			'type'    => Controls_Manager::TEXT,
			'default' => 'Elias M. Jessen'
		] );

		$testimonials7->add_control( 'designation', [
			'label'   => __( 'Designation', 'hostim-core' ),
			'type'    => Controls_Manager::TEXT,
			'default' => 'Co-Founder'
		] );

		$testimonials7->add_control( 'review_content', [
			'label'   => __( 'Review Content', 'hostim-core' ),
			'type'    => Controls_Manager::TEXTAREA,
		] );

		$testimonials7->add_control( 'rating', [
			'label'   => __( 'Rating Number', 'hostim-core' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => '50',
			'options' => [
				'10' => __( '1 Star', 'hostim-core' ),
				'20' => __( '2 Star', 'hostim-core' ),
				'30' => __( '3 Star', 'hostim-core' ),
				'40' => __( '4 Star', 'hostim-core' ),
				'50' => __( '5 Star', 'hostim-core' ),
			],
		] );

		$this->add_control( 'testimonials10', [
			'label'       => __( 'Testimonial Items', 'hostim-core' ),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => $testimonials7->get_controls(),
			'title_field' => '{{{ name }}}',
			'condition' => [
				'layout' => '10'
			]
		] );

		$this->end_controls_section();


		//==================== Carousel Settings ===================//
		$this->start_controls_section(
		    'carousel_settings', [
			    'label' => __( 'Carousel Settings', 'hostim-core' ),
				'condition' => [
					'layout' => [ '2', '3', '5', '6', '8', '9', '10' ]
				]
		    ]
	    );
	    $this->add_control(
		    'show_items_desktop', [
			    'label'     => esc_html__( 'Display Items [Desktop]', 'hostim-core' ),
			    'type'      => Controls_Manager::NUMBER,
				'default' => 1
		    ]
	    );
	    $this->add_control(
		    'show_items_tablet', [
			    'label'     => esc_html__( 'Display Items [Tablet]', 'hostim-core' ),
			    'type'      => Controls_Manager::NUMBER,
			    'default' => 1
		    ]
	    );
	    $this->add_control(
		    'show_items_mobile', [
			    'label'     => esc_html__( 'Display Items [Mobile]', 'hostim-core' ),
			    'type'      => Controls_Manager::NUMBER,
                'default'	=> 1
		    ]
	    );
	    $this->add_control(
		    'item_space',
		    [
			    'label' => __( 'Item Space', 'hostim-core' ),
			    'type' => Controls_Manager::SLIDER,
			    'size_units' => [ 'px' ],
			    'range' => [
				    'px' => [
					    'min' => 0,
					    'max' => 200,
					    'step' => 1,
				    ]
			    ],
			    'default' => [
				    'size' => 24,
			    ]
		    ]
	    );
	    $this->add_control(
		    'carousel_autoplay',
		    [
			    'label' => __( 'Auto Play', 'hostim-core' ),
			    'type' => \Elementor\Controls_Manager::SWITCHER,
			    'label_on' => __( 'True', 'hostim-core' ),
			    'label_off' => __( 'False', 'hostim-core' ),
			    'return_value' => 'yes',
			    'default' => 'yes',
		    ]
	    );
	    $this->add_control(
		    'carousel_loop',
		    [
			    'label' => __( 'Loop', 'hostim-core' ),
			    'type' => \Elementor\Controls_Manager::SWITCHER,
			    'label_on' => __( 'True', 'hostim-core' ),
			    'label_off' => __( 'False', 'hostim-core' ),
			    'return_value' => 'yes',
			    'default' => 'yes',
		    ]
	    );
	    $this->add_control(
		    'slide_speed', [
			    'label' => esc_html__( 'Slide Speed', 'hostim-core' ),
			    'type' => Controls_Manager::NUMBER,
			    'min' => 0,
			    'max' => 5000,
			    'step' => 1,
                'default' => 500
		    ]
	    );
	    $this->end_controls_section();

		// Button Setting =====================
		$this->start_controls_section( 'button_section', [
			'label' => esc_html__( 'Button', 'hostim-core' ),
			'condition' => [
				'layout' => ['1', '4']
			]
		] );

		$this->add_control( 'btn_label', [
			'label'       => __( 'Button Label', 'hostim-core' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => __( 'More Feedback', 'hostim-core' ),
			'label_block' => true,
		] );

		$this->add_control( 'btn_url', [
			'label'       => __( 'Button URL', 'hostim-core' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => __( '#', 'hostim-core' ),
			'label_block' => true,
		] );

		$this->add_control( 'btn_before_image', [
			'label'   => __( 'Button Before Image', 'hostim-core' ),
			'type'    => Controls_Manager::MEDIA,
			'default' => [
				'url' => plugin_dir_url(__DIR__) . '/assets/images/testimonial/arrow-dark.png',
			],
			'condition' => [
				'layout' => '4'
			]
		] );

		$this->end_controls_section();


		// Section heading =================
		$this->start_controls_section( 'title_style_section', [
			'label' => __( 'Section Heading', 'hostim-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
			'condition'	=> [
				'layout' => ['1', '4']
			]
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'title_typography',
			'label'    => __( 'Typography', 'hostim-core' ),
			'selector' => '
				{{WRAPPER}} .feedbackt-top h2,
				{{WRAPPER}} .testimonial-title,
				{{WRAPPER}} .section-title .testimonial_heading
			',
		] );

		$this->add_control( 'title_color', [
			'label'     => __( 'Color', 'hostim-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .testimonial-title' => 'color: {{VALUE}}',
				'{{WRAPPER}} .section-title .testimonial_heading' => 'color: {{VALUE}}',
				'{{WRAPPER}} .feedbackt-top h2' => 'color: {{VALUE}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'subtitle_typography',
			'label'    => __( 'Typography', 'hostim-core' ),
			'selector' => '
				{{WRAPPER}} .feedbackt-top p
			',
		] );

		$this->add_control( 'subtitle_color', [
			'label'     => __( 'Color', 'hostim-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .feedbackt-top p' => 'color: {{VALUE}}',
			],
		] );

		$this->end_controls_section();



		// Style Sections
		//=====================
		$this->start_controls_section( 'name_section', [
			'label' => __( 'Name', 'hostim-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'name_typography',
			'label'    => __( 'Typography', 'hostim-core' ),
			'selector' => '
				{{WRAPPER}} .name,
				{{WRAPPER}} .sh-feedback-client .t_author_name
				
				',
		] );

		$this->add_control( 'name_color', [
			'label'     => __( 'Color', 'hostim-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .name' => 'color: {{VALUE}}',
				'{{WRAPPER}} .sh-feedback-client .t_author_name' => 'color: {{VALUE}}',
			],
		] );

		$this->end_controls_section();


        //==================== Designation =====================//
		$this->start_controls_section( 'designation_section', [
			'label' => __( 'Designation', 'hostim-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'desi_typography',
			'label'    => __( 'Typography', 'hostim-core' ),
			'selector' => '
			    {{WRAPPER}} .sh-feedback-client .designation,
			    {{WRAPPER}} .designation
            ',
		] );

		$this->add_control( 'desi_color', [
			'label'     => __( 'Color', 'hostim-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .sh-feedback-client .designation' => 'color: {{VALUE}}',
				'{{WRAPPER}} .designation' => 'color: {{VALUE}}',
			],
		] );

		$this->end_controls_section(); //End Designation


		// Style Review Content
		//=========================
		$this->start_controls_section( 'review_section', [
			'label' => __( 'Review Content', 'hostim-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'review_typography',
			'label'    => __( 'Typography', 'hostim-core' ),
			'selector' => '
				{{WRAPPER}} .testimonial p,
				{{WRAPPER}} .sh-feedback-wrapper .review_content,
				{{WRAPPER}} .review_content
			',
		] );

		$this->add_control( 'review_color', [
			'label'     => __( 'Color', 'hostim-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .testimonial p' => 'color: {{VALUE}}',
				'{{WRAPPER}} .sh-feedback-wrapper .review_content' => 'color: {{VALUE}}',
				'{{WRAPPER}} .review_content' => 'color: {{VALUE}}',
			],
		] );

		$this->add_control(
			'rating_space',
			[
				'label' => esc_html__( 'Ratting Bottom Space', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .star-rating' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
				'condition' => ['layout' => '2']
			]
		);

		$this->end_controls_section();

		// Style Slider Control Section
		//================================
		$this->start_controls_section( 'control_section', [
			'label' => __( 'Slide Navigation', 'hostim-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
			'condition' => [
				'layout' => '5'
			]
		] );

		$this->start_controls_tabs('tabs_nav_style');

		$this->start_controls_tab(
			'tab_nav_normal',
			[
				'label' => __('Normal', 'hostim-core'),
			]
		);

		$this->add_control( 'slider_nav_color', [
			'label'     => __( 'Color', 'hostim-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .hostim-testimonial-wrapper .slider-control > div' => 'color: {{VALUE}}',
			],
		] );

		$this->add_control( 'nav_bg_color', [
			'label'     => __( 'Background Color', 'hostim-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .hostim-testimonial-wrapper .slider-control > div' => 'background-color: {{VALUE}}',
			],
		] );

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'nav_box_shadow',
				'label' => __( 'Box Shadow', 'hostim-core' ),
				'selector' => '{{WRAPPER}} .hostim-testimonial-wrapper .slider-control > div',
			]
		);

		$this->end_controls_tab();


		$this->start_controls_tab(
			'tab_nav_hover',
			[
				'label' => __('Hover', 'hostim-core'),
			]
		);

		$this->add_control( 'nav_color_hover', [
			'label'     => __( 'Color', 'hostim-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .hostim-testimonial-wrapper .slider-control > div:hover' => 'color: {{VALUE}}',
			],
		] );

		$this->add_control( 'nav_color_bg_hover', [
			'label'     => __( 'Background Color', 'hostim-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .hostim-testimonial-wrapper .slider-control > div:hover' => 'background-color: {{VALUE}}',
			],
		] );

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'nav_box_shadow_hover',
				'label' => __( 'Box Shadow', 'hostim-core' ),
				'selector' => '{{WRAPPER}} .hostim-testimonial-wrapper .slider-control > div:hover',
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();


        //===================== Box Container ===========================
        $this->start_controls_section( 'item_box_container_style', [
            'label' => __( 'Box Container', 'hostim-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
            'condition' => [
                'layout' => '7'
            ]
        ] );

        $this->add_control( 'item_box_container', [
            'label'     => __( 'Background Color', 'hostim-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .hostim_testimonials .ds-feedback-single' => 'background-color: {{VALUE}} !important',
            ],
        ] );

        $this->end_controls_section(); //Box Container




		// Style Section Background ================================
		$this->start_controls_section( 'testimonial_section', [
			'label' => __( 'Section Background', 'hostim-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control(
			'testimonial_margin',
			[
				'label' => __( 'Margin', 'hostim-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .feedback-section' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .feedback-section-full' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .home4-feedback' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .hostim_testimonials' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'testimonial_padding',
			[
				'label' => __( 'Padding', 'hostim-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .feedback-section' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .feedback-section-full' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .home4-feedback' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .hostim_testimonials' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'testimonial_background',
				'label' => __( 'Background', 'hostim-core' ),
				'types' => [ 'classic', 'gradient'],
				'exclude' => ['image'],
				'selector' => '
					{{WRAPPER}} .feedback-section,
					{{WRAPPER}} .feedback-section-full,
					{{WRAPPER}} .home4-feedback,
					{{WRAPPER}} .hostim_testimonials
				',
			]
		);

		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		extract( $settings );

		require __DIR__ . '/templates/testimonial/layout-'.$layout.'.php';

	}


}
