<?php
/**
 * Hostim_Services custom post type.
 *
 * @package Hostim Core
 * @since   1.0.0
 */

// Prevent loading this file directly
defined( 'ABSPATH' ) || exit;

class Hostim_Services {
	/**
	 * Construct function.
	 *
	 * @return  void
	 */
	function __construct() {
		add_action( 'init', array( __CLASS__, 'hostim_services_init' ) );
		add_filter( 'single_template', array( $this, 'portfolio_single' ) );
	}

	/**
	 * Register a Hostim_Services post type.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/register_post_type
	 */
	public static function hostim_services_init() {
		if ( function_exists( 'hostim_option' ) ) {
			$slug_text = hostim_option( 'services_slug' );
		}

		$slug = ! empty( $slug_text ) ? $slug_text : 'services';

		register_post_type( 'services', array(
			'public'             => true,
			'publicly_queryable' => true,
			'show_ui'            => true,
			'show_in_menu'       => true,
			'query_var'          => true,
			'rewrite'            => array( 'slug' => $slug ),
			'capability_type'    => 'post',
			'has_archive'        => false,
			'hierarchical'       => false,
			'show_in_rest'       => true,
			'menu_position'      => 20,
			'menu_icon'          => 'dashicons-images-alt2',
			'supports'           => array( 'title', 'editor', 'thumbnail', 'comments', 'elementor' ),
			'labels'             => array(
				'name'               => _x( 'Service', 'hostim-core' ),
				'singular_name'      => _x( 'Service', 'hostim-core' ),
				'menu_name'          => _x( 'Service', 'hostim-core' ),
				'name_admin_bar'     => _x( 'Services', 'hostim-core' ),
				'add_new'            => _x( 'Add New', 'hostim-core' ),
				'add_new_item'       => __( 'Add New Service', 'hostim-core' ),
				'new_item'           => __( 'New Service', 'hostim-core' ),
				'edit_item'          => __( 'Edit Services', 'hostim-core' ),
				'view_item'          => __( 'View Service', 'hostim-core' ),
				'all_items'          => __( 'All Services', 'hostim-core' ),
				'search_items'       => __( 'Search Services', 'hostim-core' ),
				'parent_item_colon'  => __( 'Parent Services:', 'hostim-core' ),
				'not_found'          => __( 'No Services found.', 'hostim-core' ),
				'not_found_in_trash' => __( 'No Services found in Trash.', 'hostim-core' )
			),
		) );

		// Register Services category
		register_taxonomy( 'services_cat', array( 'services' ), array(
			'hierarchical' => true,
			'show_ui'      => true,
			'show_in_rest' => true,

			'show_admin_column' => true,
			'query_var'         => true,
			'rewrite'           => array( 'slug' => 'services_cat' ),
			'labels'            => array(
				'name'              => _x( 'Categories', 'hostim-core' ),
				'singular_name'     => _x( 'Category', 'hostim-core' ),
				'search_items'      => __( 'Search Categories', 'hostim-core' ),
				'all_items'         => __( 'All Categories', 'hostim-core' ),
				'parent_item'       => __( 'Parent Category', 'hostim-core' ),
				'parent_item_colon' => __( 'Parent Category:', 'hostim-core' ),
				'edit_item'         => __( 'Edit Category', 'hostim-core' ),
				'update_item'       => __( 'Update Category', 'hostim-core' ),
				'add_new_item'      => __( 'Add New Category', 'hostim-core' ),
				'new_item_name'     => __( 'New Category Name', 'hostim-core' ),
				'menu_name'         => __( 'Categories', 'hostim-core' ),
			),
		) );


		//Register Services tag
		register_taxonomy( 'services_tag', 'services', array(
			'hierarchical'          => true,
			'show_ui'               => true,
			'show_admin_column'     => true,
			'update_count_callback' => '_update_post_term_count',
			'query_var'             => true,
			'rewrite'               => array( 'slug' => 'services_tag' ),
			'labels'                => array(
				'name'                       => _x( 'Tags', 'hostim-core' ),
				'singular_name'              => _x( 'Tag', 'hostim-core' ),
				'search_items'               => __( 'Search Tags', 'hostim-core' ),
				'popular_items'              => __( 'Popular Tags', 'hostim-core' ),
				'all_items'                  => __( 'All Tags', 'hostim-core' ),
				'parent_item'                => null,
				'parent_item_colon'          => null,
				'edit_item'                  => __( 'Edit Tag', 'hostim-core' ),
				'update_item'                => __( 'Update Tag', 'hostim-core' ),
				'add_new_item'               => __( 'Add New Tag', 'hostim-core' ),
				'new_item_name'              => __( 'New Tag Name', 'hostim-core' ),
				'separate_items_with_commas' => __( 'Separate tag with commas', 'hostim-core' ),
				'add_or_remove_items'        => __( 'Add or remove tag', 'hostim-core' ),
				'choose_from_most_used'      => __( 'Choose from the most used tag', 'hostim-core' ),
				'not_found'                  => __( 'No tag found.', 'hostim-core' ),
				'menu_name'                  => __( 'Tags', 'hostim-core' ),
			),
		) );
	}

	/**
	 * Load single item template file for the Services custom post type.
	 *
	 * @param string $template Current template file.
	 *
	 * @return  string
	 */
	function portfolio_single( $template ) {
		global $post;

		if ( $post->post_type == 'services' ) {
			$template = HOSTIM_CORE_DIR . 'inc/post-type/services/views/single.php';
		}

		return $template;
	}


	/**
	 * Define helper function to print related Services.
	 *
	 * @return  array
	 */
	public static function related() {

		global $post;
		// Get the good menu tags.
		$cats = get_the_terms( $post, 'services_cat' );

		if ( $cats ) {
			$cat_ids = array();

			foreach ( $cats as $cat ) {
				$cat_ids[] = $cat->term_id;
			}

			$post_perpage = hostim_option( 'relpost_count' ) ? hostim_option( 'relpost_count' ) : (int) '3';

			$args = array(
				'post_type'      => 'services',
				'post__not_in'   => array( $post->ID ),
				'posts_per_page' => 3,
				'tax_query'      => array(
					array(
						'taxonomy' => 'services_cat',
						'field'    => 'id',
						'terms'    => $cat_ids,
					),
				)
			);

			$the_query = new WP_Query( $args );

			?>

			<div class="related-services">
				<div class="container">
					<?php if ( hostim_option( 'related_services' ) || hostim_option( 'port_sub_title' ) !== '' ) { ?>
						<div class="section-heading style-one text-center">
							<?php if ( hostim_option( 'services_title' ) !== "" ) : ?>
								<h2 class="section-title"><?php echo esc_html( hostim_option( 'services_title' ) ) ?> </h2>
							<?php endif; ?>

							<?php if ( ! empty( hostim_option( 'title_description' ) )) :?>
							<p class="description">
								<?php echo wp_kses_post( hostim_option( 'title_description' ) ) ?>
							</p>
						<?php endif; ?>

						</div>
					<?php } ?>
					<div class="row">

						<?php

						if ( $the_query->have_posts() ) :
							while ( $the_query->have_posts() ) :
								$the_query->the_post();
								$meta = get_post_meta( get_the_ID(), 'hostim_services_options', true );
								?>

								<div class="col-md-6">
									<div <?php post_class( 'hostim-services services-light' ); ?>>
										<p class="hostim-services__type">
											<i class="fas fa-briefcase"></i>
											<span class="hostim-Services__type-text"><?php echo esc_html( $meta['Services_type'] ); ?></span>
										</p>

										<h3 class="hostim-Services__title">
											<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
										</h3>

										<ul class="hostim-Services__info">
											<li>
												<i class="fas fa-building"></i>
												<span class="hostim-Services__info-text"><?php echo esc_html( $meta['company_name'] ); ?></span>
											</li>
											<li>
												<i class="fas fa-map-marker-alt"></i>
												<span class="hostim-Services__info-text"><?php echo esc_html( $meta['company_location'] ); ?></span>
											</li>
											<li>
												<i class="fas fa-wallet"></i>
												<span class="hostim-services__info-text"><?php echo esc_html( $meta['salary'] ); ?></span>
											</li>
										</ul>

										<div class="hostim-services__categories">
											<?php

											$terms = get_the_terms( get_the_ID(), 'services_cat' );

											if ( $terms && ! is_wp_error( $terms ) ) :
												foreach ( $terms as $term ) { ?>
													<span class="hostim-services__category"><?php echo $term->name; ?></span>
												<?php } ?>
											<?php endif; ?>

										</div>

										<a href="<?php echo esc_url( get_the_permalink() ) ?>" class="hostim-btn"><?php echo esc_html__( 'Apply Now', 'hostim-core' ) ?></a>
									</div>
								</div>
								<!-- /.col-md-6 -->
							<?php endwhile;
							wp_reset_postdata();
						endif; ?>
					</div>
				</div>
			</div>
		<?php }
		wp_reset_postdata();
	}
}

$portfolio = new Hostim_Services;