<?php
/**
 * Job single.
 *
 * @package Hostim_Core
 * @since   1.0.0
 */

get_header();
$meta = get_post_meta( get_the_ID(), 'hostim_job_options', true );

?>

	<section class="page-header">
		<div class="container mt-5">
			<div class="row">
				<div class="col-md-9">
					<div class="job-header">
						<?php if ( ! empty( $meta['company_logo']['url'] ) ) : ?>
							<div class="job-logo">
								<img src="<?php echo esc_url( $meta['company_logo']['url'] ); ?>" alt="<?php echo esc_attr( the_title() ); ?>">
							</div>
						<?php endif; ?>

						<div class="header-content">
							<h1 class="single-post-title"><?php the_title(); ?></h1>

							<?php if ( ! empty( $meta['company_short_info'] ) ) : ?>
								<p class="company-short-description">
									<?php echo esc_html( $meta['company_short_info'] ); ?>
								</p>
							<?php endif; ?>

							<ul class="company-info">

								<?php if (! empty($meta['company_name']) ) : ?>
									<li><i class="far fa-building"></i><?php echo esc_html( $meta['company_name'] ); ?></li>
								<?php endif; ?>
								<?php
								$rating = $meta['rating'];
								$rating_markup = "<div class='star-rating hostim-star-" . $rating . "'>\n";
								$rating_markup .= "<span class=\"hostim-star-1 fa-star\"></span>\n";
								$rating_markup .= "<span class=\"hostim-star-2 fa-star\"></span>\n";
								$rating_markup .= "<span class=\"hostim-star-3 fa-star\"></span>\n";
								$rating_markup .= "<span class=\"hostim-star-4 fa-star\"></span>\n";
								$rating_markup .= "<span class=\"hostim-star-5 fa-star\"></span>\n";
								$rating_markup .= "</div>";
								?>
								<?php if (! empty($rating) ) : ?>
									<li>
										<i class="far fa-smile"></i>
										<?php echo $rating_markup; ?>
									</li>
								<?php endif; ?>

								<?php if (! empty($meta['company_location']) ) : ?>
									<li>
										<i class="fas fa-map-marker-alt"></i><?php echo esc_html( $meta['company_location'] ); ?>
									</li>
								<?php endif; ?>
							</ul>
							<!-- /.company-info -->

						</div>
						<!-- /.header-content -->
					</div>
					<!-- /.job-header -->


				</div>

				<?php if (! empty($meta['salary_title'] && $meta['salary'] ) ) : ?>
					<div class="col-md-3">
						<div class="salary-info">
							<?php if ( ! empty( $meta['salary_title'] ) ) : ?>
								<h3 class="salary-title"><?php echo esc_html( $meta['salary_title'] ); ?></h3>
							<?php endif; ?>

							<?php if ( ! empty( $meta['salary'] ) ) : ?>
								<p class="salary"><?php echo esc_html( $meta['salary'] ); ?></p>
							<?php endif; ?>

						</div>
						<!-- /.salary-info -->
					</div>
				<?php endif; ?>

			</div>
			<!-- /.row -->
		</div>
		<!-- /.container -->
	</section>
	<!-- /.page-header -->

	<section class="job_details_area">
		<div class="container">
			<div class="job-single">
				<?php while ( have_posts() ) : the_post(); ?>
					<div class="job-feature-image">
						<?php if ( has_post_thumbnail() ) {
							echo the_post_thumbnail( 'hostim-job-single' );
						} ?>
					</div>
					<div class="content-inner">
						<div class="row">
							<div class="col-md-8">
								<?php the_content(); ?>
							</div>
							<!-- /.col-md-8 -->

							<div class="col-md-4">
								<div class="job-information">
									<h3 class="job-info-title"><?php echo esc_html( $meta['job_info_title'] ); ?></h3>
									<?php if ( is_array( $meta['company_infos'] ) ) : ?>
										<ul class="job-info-items">
											<?php foreach ( $meta['company_infos'] as $info ) : ?>
												<li>
													<i class="<?php echo $info['info_icon'] ?>"></i>
													<div class="info-content">
														<h4 class="info-title"><?php echo esc_html( $info['info_title'] ) ?></h4>
														<p><?php echo esc_html( $info['info'] ) ?></p>
													</div>
													<!-- /.info-content -->
												</li>
											<?php endforeach; ?>
										</ul>
										<!-- /.job-info-items -->
									<?php endif; ?>

									<?php
										$button = $meta['apply_btn'];
									?>

									<?php if( ! empty( $button['url'] )) : ?>
										<a href="<?php echo esc_attr($button['url']); ?>" class="hostim-btn mt-4"><?php echo esc_html($button['text']); ?></a>
									<?php endif; ?>

								</div>
								<!-- /.job-information -->
							</div>
							<!-- /.col-md-4 -->
						</div>
						<!-- /.row -->
					</div><!-- /.content-inner -->

				<?php endwhile;
				wp_reset_postdata();
				?>
			</div><!-- .job-single -->
		</div>
		<!-- /.container -->
	</section>

	<?php

	Hostim_Job::related();
?>


<?php get_footer();